@@ -100,7 +100,11 @@
                         dataType: 'json',
                         data: "term=" + request.term + "&app_label=" + grappelli.get_app_label(elem) + "&model_name=" + grappelli.get_model_name(elem) + "&query_string=" + grappelli.get_query_string(elem),
                         beforeSend: function (XMLHttpRequest) {
-                            options.loader.show();
+                            if ($(options.content_type).val()) {
+                                options.loader.show();
+                            } else {
+                                return false;
+                            }
                         },
                         success: function(data){
                             response($.map(data, function(item) {
